[−][src]Function mief::execution_flow::exit::fail_from_error
pub fn fail_from_error(error: Error) -> !
Quit the program execution. The exit code and message are chosen based on error.
pub fn fail_from_error(error: Error) -> !
Quit the program execution. The exit code and message are chosen based on error.